import React from 'react';
import style from './index.less';
import {
  DatePicker,
  Select,
  Button,
  Row,
  Col,
  Dropdown,
  Menu,
  TreeSelect,
} from 'antd';
const { Option } = Select;
import moment from 'moment';
import 'moment/locale/zh-cn';
import locale from 'antd/lib/date-picker/locale/zh_CN';
moment.locale('zh-cn');

export class TopBar extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      deptartmentTreeData: [], //部门异步树
      treeExpandedKeys: [],
      levelOptions: [], //层级数据，hrm中层级字段
      requestData: {
        date: moment(new Date()).format('YYYY-MM-DD'), //日期
        department: undefined,
        level: '0', //显示层级
      },
    };
  }

  handleFormChange(payload) {
    let requestData = { ...this.state.requestData, ...payload };
    this.setState({ requestData });
  }

  handleExportMenuClick(e) {
    this.props.onExport(e.key == '1' ? 'png' : 'pdf');
  }

  /**
   * 部门树数据
   * @param {} parentId
   * @returns
   */
  getDepartmentTreeNode = (parentId) => {
    let api = '/api/ais/orgChart/getDepartmentTree?department=' + parentId;
    fetch(api)
      .then((res) => res.json())
      .then((data) => {
        if (data.status) {
          let arr = [...this.state.deptartmentTreeData, ...data.data.deptTree];
          this.setState({
            deptartmentTreeData: arr,
          });
        }
      });
  };

  /**
   * 部门树异步加载
   * @param {} parentId
   * @returns
   */
  onDepartmentLoadData = (treeNode) =>
    new Promise((resolve) => {
      const { id } = treeNode.props;
      setTimeout(() => {
        this.getDepartmentTreeNode(id);
        resolve(undefined);
      }, 1000);
    });

  onDepartmentChange = (value) => {
    let requestData = { ...this.state.requestData, department: value };
    this.setState({ departmentData: value, requestData });
  };

  paramsUtil = (param) => {
    let arr = param.map(function (obj, index) {
      return obj.value;
    });
    return arr.join(',');
  };

  onTreeExpand = (expandedKeys) => {
    this.setState({
      treeExpandedKeys: expandedKeys,
    });
  };

  componentDidMount() {
    fetch(this.props.url)
      .then((res) => res.json())
      .then((data) => {
        if (data.status) {
          this.setState({
            levelOptions: data.data.deptLevel,
            deptartmentTreeData: data.data.deptTree,
          });
        }
      });
  }

  /**
   * 导出多选 */
  menu = (
    <Menu
      onClick={this.handleExportMenuClick.bind(this)}
      items={[
        {
          label: '导出图片',
          key: '1',
        },
        {
          label: '导出PDF',
          key: '2',
        },
      ]}
    />
  );

  render() {
    const { deptartmentTreeData } = this.state;
    return (
      <div className={style.topbarWrapper}>
        <Row gutter={[16, 16]}>
          <Col span={6}>
            日期追溯：
            <DatePicker
              placeholder="日期选择"
              style={{ width: 150 }}
              locale={locale}
              allowClear={false}
              //disabledDate={this.disabledDate}
              defaultValue={moment(new Date())}
              value={
                this.state.requestData.date && this.state.requestData.date != ''
                  ? moment(this.state.requestData.date)
                  : ''
              }
              onChange={(value) =>
                this.handleFormChange({
                  date: value && value != '' ? value.format('YYYY-MM-DD') : '',
                })
              }
            />
          </Col>
          <Col span={6}>
            部门：
            <TreeSelect
              treeDataSimpleMode
              allowClear
              style={{ width: '80%' }}
              value={this.state.requestData.department}
              dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
              placeholder="请选择部门节点"
              onChange={this.onDepartmentChange}
              loadData={this.onDepartmentLoadData}
              treeData={deptartmentTreeData}
            />
          </Col>
          <Col span={6}>
            部门层级：
            <Select
              style={{ width: 130 }}
              value={this.state.requestData.level}
              onChange={(value) => this.handleFormChange({ level: value })}
              options={this.state.levelOptions}
            />
          </Col>
          <Col span={6}>
            <Button
              type="primary"
              style={{ marginRight: '10px' }}
              onClick={() => {
                this.props.onSearch(this.state.requestData);
              }}
            >
              查询
            </Button>
            <Button
              type="primary"
              style={{ marginRight: '10px' }}
              onClick={() => {
                window.open('#/chart', '_blank');
              }}
            >
              图谱
            </Button>
            <Dropdown overlay={this.menu}>
              <Button type="primary">导出</Button>
            </Dropdown>
          </Col>
        </Row>
      </div>
    );
  }
}
